.. module:: tests.panelist

panelist
========

This module provides functions used to by :py:class:`pytest` to run tests against
the following objects:

- :py:class:`wwdtm.panelist.Panelist`
- :py:class:`wwdtm.panelist.PanelistAppearances`
- :py:class:`wwdtm.panelist.PanelistScores`
- :py:class:`wwdtm.panelist.PanelistStatistics`
- :py:class:`wwdtm.panelist.PanelistUtility`


test_panelist_appearances
-------------------------

.. automodule:: tests.panelist.test_panelist_appearances
    :members:
    :undoc-members:

test_panelist_panelist
----------------------

.. automodule:: tests.panelist.test_panelist_panelist
    :members:
    :undoc-members:

test_panelist_scores
--------------------

.. automodule:: tests.panelist.test_panelist_scores
    :members:
    :undoc-members:

test_panelist_statistics
------------------------

.. automodule:: tests.panelist.test_panelist_statistics
    :members:
    :undoc-members:

test_panelist_utility
---------------------

.. automodule:: tests.panelist.test_panelist_utility
    :members:
    :undoc-members:
